@@ -255,70 +255,6 @@ class QueryContainer(Stereo, Graph[Query, QueryBond], QuerySmiles):
             else:
                 yield copy
 
-    @cached_property
-    def _screen_fingerprints(self) -> Tuple[Dict[int, Set[int]], ...]:
-        """
-        Fingerprints of all possible simple queries. Used for isomorphism tests filtering.
-        """
-        from chython import fingerprint_config
-
-        if not fingerprint_config or any(isinstance(a, (AnyElement, AnyMetal)) for _, a in self.atoms()):
-            return ()  # skip queries with Any element
-
-        fps = []
-        for q in self.enumerate_queries():
-            mol = molecule.MoleculeContainer()
-            for n, a in q.atoms():
-                mol.add_atom(Element.from_atomic_number(a.atomic_number)(a.isotope), n,
-                             charge=a.charge, is_radical=a.is_radical)
-            for n, m, b in q.bonds():
-                mol.add_bond(n, m, Bond(b.order[0]))
-
-            # extract only longest chains
-            chains = []
-            for c in sorted(mol._chains(**fingerprint_config), reverse=True, key=len):
-                sc = set(c)
-                if any(sc.issubset(x) for x in chains):
-                    continue
-                chains.append(c)
-            if not chains:
-                continue
-
-            atoms = {idx: hash((atom.isotope or 0, atom.atomic_number, atom.charge, atom.is_radical))
-                     for idx, atom in mol.atoms()}
-            bonds = mol._bonds
-            out = defaultdict(list)
-
-            for frag in chains:
-                var = [atoms[frag[0]]]
-                for x, y in zip(frag, frag[1:]):
-                    var.append(int(bonds[x][y]))
-                    var.append(atoms[y])
-                var = tuple(var)
-                rev_var = var[::-1]
-                out[hash(var if var > rev_var else rev_var)].extend(frag)
-
-            fps.append({k: set(v) for k, v in out.items()})
-        return tuple(fps)
-
-    @cached_args_method
-    def _component_fingerprints(self, component):
-        """
-        Fingerprints of specific component.
-        """
-        scope = set(self.connected_components[component])
-        return tuple({k for k, v in fp.items() if not v.isdisjoint(scope)} for fp in self._screen_fingerprints)
-
-    def _isomorphism_candidates(self, other, self_component, other_component):
-        if self._screen_fingerprints and isinstance(other, molecule.MoleculeContainer):
-            other_fingerprint = other._component_fingerprint(other_component)
-            scope = set()
-            for fp in self._component_fingerprints(self_component):
-                if fp <= other_fingerprint.keys():
-                    scope.update(x for k in fp for x in other_fingerprint[k])
-            return scope
-        return super()._isomorphism_candidates(other, self_component, other_component)
-
     @cached_property
     def _cython_compiled_query(self):
         # long I:
